package ttakada;

import com.idiominc.wssdk.asset.WSAssetTranslation;
import com.idiominc.wssdk.asset.WSTextSegmentPlaceholder;
import com.idiominc.wssdk.asset.WSTextSegmentTranslation;
import com.idiominc.wssdk.asset.WSTranslationStatus;
import com.idiominc.wssdk.asset.WSTranslationType;
import com.idiominc.wssdk.linguistic.WSLanguage;
import com.idiominc.wssdk.linguistic.WSLanguagePair;
import com.idiominc.wssdk.mt.WSMTAdapter;
import com.idiominc.wssdk.mt.WSMTConfiguration;
import com.idiominc.wssdk.mt.WSMTResult;
import com.idiominc.wssdk.mt.WSMTService;
import org.apache.log4j.Logger;

import java.util.Iterator;

//  Forwarding class
public class MyMTServiceComposition implements WSMTService {
    private static final Logger log = Logger.getLogger(MyMTServiceComposition.class);

    private final WSMTService baseMt;

    public MyMTServiceComposition(WSMTService baseService) {
        this.baseMt = baseService;
    }

    @Override
    public void translate(WSAssetTranslation assetTranslation, double score) {
        WSLanguage source = assetTranslation.getSourceLanguage();
        WSLanguage target = assetTranslation.getTargetLanguage();

        Iterator iterator = assetTranslation.textSegmentIterator();

        while(iterator.hasNext()) {
            WSTextSegmentTranslation segment = (WSTextSegmentTranslation) iterator.next();
            log.warn("TEXT: " + segment.getSource());

            WSTextSegmentPlaceholder[] placeholders = segment.getSourcePlaceholders();
            for(WSTextSegmentPlaceholder ph : placeholders) {
                if(ph.getMarkupInfo().isStartTag()) {
                    if(ph.getMarkupInfo().getText().equalsIgnoreCase("<i>")) {
                        segment.setComments("There is an italic tag");
                    }
                }
                log.warn(String.format("%d: %s | %s | %s", ph.getId(), ph.getText(), ph.getMarkupInfo().getTagId(), ph.getMarkupInfo().getText()));
            }

            WSMTResult[] results = translate(segment.getSource(), source, target);

            if(results.length > 0) {
                segment.setTarget(results[0].getTranslation());
                segment.setTranslationStatus(WSTranslationStatus.NO_STATUS);
                segment.setTranslationType(WSTranslationType.MACHINE_TRANSLATION);
            }
        }
    }

    @Override
    public WSMTResult[] translate(String s, WSLanguage source, WSLanguage target) {
        WSMTResult[] translates = baseMt.translate(s, source, target);
        if(translates.length > 0) {
            log.warn("TRX: " + translates[0].getTranslation());
        }

        return translates;
    }

    @Override
    public WSMTConfiguration getCurrentConfiguration() {
        return baseMt.getCurrentConfiguration();
    }

    @Override
    public boolean updateMT(WSAssetTranslation assetTranslation) {
        return baseMt.updateMT(assetTranslation);
    }

    @Override
    public boolean updatable() {
        return baseMt.updatable();
    }

    @Override
    public void setCurrentConfiguration(WSMTConfiguration configuration) {
        baseMt.setCurrentConfiguration(configuration);
    }

    @Override
    public WSLanguagePair[] getSupportedLanguagePairs() {
        return baseMt.getSupportedLanguagePairs();
    }

    @Override
    public String getDisplayString() {
        return baseMt.getDisplayString();
    }

    @Override
    public WSMTAdapter getAdapter() {
        return baseMt.getAdapter();
    }
}
